=======
History
=======

0.1.9 (2020-08-29)
------------------

* Credentials can now be stored in TOML format and read automatically.

0.1.8 (2020-08-28)
------------------

* Add session status check to avoid 401 responses after a period of inactivity.

0.1.7 (2020-08-04)
------------------

* Fixed enum parsing when using CLI.

0.1.6 (2020-07-08)
------------------

* Updated enums to support new voices - Dasha, Carol Asel.


0.1.0 (2020-05-23)
------------------

* First release on PyPI.
